==> vikiwiki2-1.9.7.14.zip: vikiwiki2/vikiwiki/msg/ja.rb <==
{
# ファイルエラー
:FILE_ALREADY_MODIFIED           => "ファイルはすでに更新されています。",
:FILE_AREADY_EXISTS              => "ファイルはすでに存在しています。%1",
:FILE_NOT_FOUND                  => "ファイルまたはディレクトリが存在しません。%1",
:FILE_ALREADY_CHECKOUT           => "ファイルはすでにチェックアウトされています。",
:FILE_NOT_CHECKOUT               => "ファイルがチェックアウトされていません。",
:FILE_NOT_SPECIFIED              => "ファイル名が指定されていません。",
:FILE_INVALID_NAME               => "パスに使用できない文字が含まれています。%1",
:FILE_FULL_PATH_DENIED           => "フルパス指定はできません。",
:FILE_INVALID_EXTENTION          => "拡張子が正しくありません。",
:NOT_A_DIRECTORY                 => "ディレクトリではありません。%1",
:NOT_A_FILE                      => "ファイルではありません。%1",
# ページエラー
:PAGE_INVALID_PATH               => "ページのパスが正しくありません。%1",
:PAGE_INVALID_NAME               => "ページ名が正しくありません。%1",
:PAGE_NAME_TOO_LONG              => "ページ名が長すぎます。%1",
:PAGE_ALREADY_EXISTS             => "ページがすでに存在しています。%1",
:PAGE_NOT_FOUND                  => "ページが見つかりません。%1",
:LAYOUT_PAGE_NOT_FOUND           => "レイアウト用のページが見つかりません。%1",
:PAGE_STATIC_DENIED              => "アクセス制限のあるページは静的HTMLを作成できません。",
# 認証エラー
:AUTH_FAILED                     => "認証に失敗しました。",
# 機能エラー
:FUNC_LINK_GEN_ERROR             => "リンクの作成に失敗しました。%1",
:FUNC_THEME_NOT_LOCAL            => "テーマがローカルファイルではありません。",
:FUNC_THEME_ELM_NOT_FOUND        => "このテーマには指定された要素はありません。%1",
:FUNC_THEME_URI_INVALID_PROTCOL  => "不正なプロトコル指定です。",
:FUNC_THEME_ESCAPE_DENIED        => "スタイル中にエスケープ文字は使用できません。",
:FUNC_THEME_COMMENT_DENIED       => "スタイル中にコメントを含むことはできません。",
:FUNC_THEME_INVALID_KEYWORD      => "不正なキーワードが存在します。",
:FUNC_DIV_INVALID_CLASS          => "クラスが正しくありません。",
:FUNC_PLUGIN_NOT_FOUND           => "プラグイン%1が見つかりません。%2",
:FUNC_DUPLICATE_IMPORT           => "インポートされたページをさらにインポートしようとしました。",
}

==> vikiwiki2-1.9.8.0.zip: vikiwiki2/vikiwiki/msg/ja.rb <==
{
# ファイルエラー
:FILE_ALREADY_MODIFIED           => "ファイルはすでに更新されています。",
:FILE_AREADY_EXISTS              => "ファイルはすでに存在しています。%1",
:FILE_NOT_FOUND                  => "ファイルまたはディレクトリが存在しません。%1",
:FILE_ALREADY_CHECKOUT           => "ファイルはすでにチェックアウトされています。",
:FILE_NOT_CHECKOUT               => "ファイルがチェックアウトされていません。",
:FILE_NOT_SPECIFIED              => "ファイル名が指定されていません。",
:FILE_INVALID_NAME               => "パスに使用できない文字が含まれています。%1",
:FILE_FULL_PATH_DENIED           => "フルパス指定はできません。",
:FILE_INVALID_EXTENTION          => "拡張子が正しくありません。",
:NOT_A_DIRECTORY                 => "ディレクトリではありません。%1",
:NOT_A_FILE                      => "ファイルではありません。%1",
# ページエラー
:PAGE_INVALID_PATH               => "ページのパスが正しくありません。%1",
:PAGE_INVALID_NAME               => "ページ名が正しくありません。%1",
:PAGE_NAME_TOO_LONG              => "ページ名が長すぎます。%1",
:PAGE_ALREADY_EXISTS             => "ページがすでに存在しています。%1",
:PAGE_NOT_FOUND                  => "ページが見つかりません。%1",
:LAYOUT_PAGE_NOT_FOUND           => "レイアウト用のページが見つかりません。%1",
:PAGE_STATIC_DENIED              => "アクセス制限のあるページは静的HTMLを作成できません。",
:PAGE_INVALID_WORD               => "不正な文字列が含まれているため、書き込みを拒否しました。",
# 認証エラー
:AUTH_FAILED                     => "認証に失敗しました。",
# 機能エラー
:FUNC_LINK_GEN_ERROR             => "リンクの作成に失敗しました。%1",
:FUNC_THEME_NOT_LOCAL            => "テーマがローカルファイルではありません。",
:FUNC_THEME_ELM_NOT_FOUND        => "このテーマには指定された要素はありません。%1",
:FUNC_THEME_URI_INVALID_PROTCOL  => "不正なプロトコル指定です。",
:FUNC_THEME_ESCAPE_DENIED        => "スタイル中にエスケープ文字は使用できません。",
:FUNC_THEME_COMMENT_DENIED       => "スタイル中にコメントを含むことはできません。",
:FUNC_THEME_INVALID_KEYWORD      => "不正なキーワードが存在します。",
:FUNC_DIV_INVALID_CLASS          => "クラスが正しくありません。",
:FUNC_PLUGIN_NOT_FOUND           => "プラグイン%1が見つかりません。%2",
:FUNC_DUPLICATE_IMPORT           => "インポートされたページをさらにインポートしようとしました。",
:FUNC_NOT_SUPPORTED              => "%1機能はサポートされていません。",
}
